{% extends "base.html" %}
{% load static %}
{% load i18n %}
{% block content %}
<p><a class="btn btn-default" href="{% url 'pyfb-kamailio:pyfb_kamailio_locationattrs_list' %}">LocationAttrs Listing</a></p>
<table class="table">
<tr><td>ruid</td><td>{{ object.ruid }}</td></tr>
<tr><td>username</td><td>{{ object.username }}</td></tr>
<tr><td>domain</td><td>{{ object.domain }}</td></tr>
<tr><td>aname</td><td>{{ object.aname }}</td></tr>
<tr><td>atype</td><td>{{ object.atype }}</td></tr>
<tr><td>avalue</td><td>{{ object.avalue }}</td></tr>
<tr><td>last_modified</td><td>{{ object.last_modified }}</td></tr>
</table>
<a class="btn btn-primary" href="{{object.get_update_url}}">Edit LocationAttrs</a>

{% endblock %}
