# Generated by Django 2.1.5 on 2019-01-30 17:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_kamailio', '0002_auto_20190130_1634'),
    ]

    operations = [
        migrations.CreateModel(
            name='Statistic',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('kamailio_id', models.PositiveSmallIntegerField()),
                ('time_stamp', models.IntegerField(default=0)),
                ('random', models.IntegerField(default=0)),
                ('shm_used_size', models.IntegerField(default=0)),
                ('shm_real_used_size', models.IntegerField(default=0)),
                ('shm_max_used_size', models.IntegerField(default=0)),
                ('shm_free_used_size', models.IntegerField(default=0)),
                ('ul_users', models.IntegerField(default=0)),
                ('ul_contacts', models.IntegerField(default=0)),
            ],
            options={
                'db_table': 'statistics',
                'ordering': ('-pk',),
            },
        ),
        migrations.AlterField(
            model_name='acccdr',
            name='end_time',
            field=models.DateTimeField(help_text='End date and time'),
        ),
        migrations.AlterField(
            model_name='acccdr',
            name='start_time',
            field=models.DateTimeField(db_index=True, help_text='Start date and time'),
        ),
        migrations.AlterField(
            model_name='location',
            name='expires',
            field=models.DateTimeField(db_index=True, help_text='Date and time when this entry expires.'),
        ),
        migrations.AlterField(
            model_name='location',
            name='last_modified',
            field=models.DateTimeField(help_text='Date and time when this entry was last modified'),
        ),
        migrations.AlterField(
            model_name='locationattrs',
            name='last_modified',
            field=models.DateTimeField(db_index=True, help_text='Date and time when this entry was last modified'),
        ),
        migrations.AlterField(
            model_name='rtpengine',
            name='disabled',
            field=models.IntegerField(choices=[(0, 'disabled'), (1, 'enabled')], default=0, help_text='RTPEngine instance state on startup'),
        ),
        migrations.AlterField(
            model_name='rtpengine',
            name='stamp',
            field=models.DateTimeField(auto_now_add=True, help_text='RTPEngine instance add timestamp'),
        ),
        migrations.AlterField(
            model_name='rtpengine',
            name='url',
            field=models.CharField(help_text='RTPEngine instance socket URL. Example : udp:rtpengine1.domain:8800', max_length=64),
        ),
        migrations.AlterField(
            model_name='rtpengine',
            name='weight',
            field=models.IntegerField(default=1, help_text='RTPEngine instance weight on startup'),
        ),
    ]
