# Generated by Django 2.1.5 on 2020-05-14 17:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_kamailio', '0012_auto_20200514_1705'),
    ]

    operations = [
        migrations.AddField(
            model_name='missedcall',
            name='call_direction',
            field=models.CharField(default='', help_text='inbound / outbound', max_length=128),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='called_destination',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='called_did',
            field=models.CharField(default='', max_length=128),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='caller_destination',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='did_destination',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='e164_called',
            field=models.CharField(default='', max_length=128),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='e164_caller',
            field=models.CharField(default='', max_length=128),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='leg_a_class',
            field=models.CharField(default='', help_text='on-net / off-net', max_length=128),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='leg_b_class',
            field=models.CharField(default='', help_text='on-net / off-net', max_length=128),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='o_c_rate_id',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='o_c_rate_type',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='o_p_rate_id',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='o_p_rate_type',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='orig_customer',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='orig_provider',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='t_c_rate_id',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='t_c_rate_type',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='t_p_rate_id',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='t_p_rate_type',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='term_customer',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='term_provider',
            field=models.IntegerField(blank=True, null=True),
        ),
    ]
