{% extends "base.html" %}
{% load static %}
{% load i18n %}
{% block content %}
<p><a class="btn btn-default" href="{% url 'pyfb-kamailio:pyfb_kamailio_speeddial_list' %}">SpeedDial Listing</a></p>
<table class="table">
<tr><td>username</td><td>{{ object.username }}</td></tr>
<tr><td>domain</td><td>{{ object.domain }}</td></tr>
<tr><td>sd_username</td><td>{{ object.sd_username }}</td></tr>
<tr><td>sd_domain</td><td>{{ object.sd_domain }}</td></tr>
<tr><td>new_uri</td><td>{{ object.new_uri }}</td></tr>
<tr><td>fname</td><td>{{ object.fname }}</td></tr>
<tr><td>lname</td><td>{{ object.lname }}</td></tr>
<tr><td>description</td><td>{{ object.description }}</td></tr>
</table>
<a class="btn btn-primary" href="{{object.get_update_url}}">Edit SpeedDial</a>

{% endblock %}
