{% extends "base.html" %}
{% load static %}
{% load i18n %}
{% block content %}
<p><a class="btn btn-default" href="{% url 'pyfb-kamailio:pyfb_kamailio_acccdr_list' %}">AccCdr Listing</a></p>
<table class="table">
<tr><td>start_time</td><td>{{ object.start_time }}</td></tr>
<tr><td>end_time</td><td>{{ object.end_time }}</td></tr>
<tr><td>duration</td><td>{{ object.duration }}</td></tr>
</table>
<a class="btn btn-primary" href="{{object.get_update_url}}">Edit AccCdr</a>

{% endblock %}
