{% extends "base.html" %}
{% load static %}
{% load i18n %}
{% block content %}
<p><a class="btn btn-default" href="{% url 'pyfb-kamailio:pyfb_kamailio_location_list' %}">Location Listing</a></p>
<table class="table">
<tr><td>ruid</td><td>{{ object.ruid }}</td></tr>
<tr><td>username</td><td>{{ object.username }}</td></tr>
<tr><td>domain</td><td>{{ object.domain }}</td></tr>
<tr><td>contact</td><td>{{ object.contact }}</td></tr>
<tr><td>received</td><td>{{ object.received }}</td></tr>
<tr><td>path</td><td>{{ object.path }}</td></tr>
<tr><td>expires</td><td>{{ object.expires }}</td></tr>
<tr><td>q</td><td>{{ object.q }}</td></tr>
<tr><td>callid</td><td>{{ object.callid }}</td></tr>
<tr><td>cseq</td><td>{{ object.cseq }}</td></tr>
<tr><td>last_modified</td><td>{{ object.last_modified }}</td></tr>
<tr><td>flags</td><td>{{ object.flags }}</td></tr>
<tr><td>cflags</td><td>{{ object.cflags }}</td></tr>
<tr><td>user_agent</td><td>{{ object.user_agent }}</td></tr>
<tr><td>socket</td><td>{{ object.socket }}</td></tr>
<tr><td>methods</td><td>{{ object.methods }}</td></tr>
<tr><td>instance</td><td>{{ object.instance }}</td></tr>
<tr><td>reg_id</td><td>{{ object.reg_id }}</td></tr>
<tr><td>server_id</td><td>{{ object.server_id }}</td></tr>
<tr><td>connection_id</td><td>{{ object.connection_id }}</td></tr>
<tr><td>keepalive</td><td>{{ object.keepalive }}</td></tr>
<tr><td>partition</td><td>{{ object.partition }}</td></tr>
</table>
<a class="btn btn-primary" href="{{object.get_update_url}}">Edit Location</a>

{% endblock %}
