# Generated by Django 2.1.5 on 2020-05-14 15:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_kamailio', '0010_auto_20200321_1551'),
    ]

    operations = [
        migrations.AlterField(
            model_name='dialogvar',
            name='dialog_value',
            field=models.TextField(help_text='The value of the dialog variable'),
        ),
    ]
