{% extends "base.html" %}
{% load static %}
{% load i18n %}
{% block content %}
<p><a class="btn btn-default" href="{% url 'pyfb-kamailio:pyfb_kamailio_pipelimit_list' %}">PipeLimit Listing</a></p>
<table class="table">
<tr><td>pipeid</td><td>{{ object.pipeid }}</td></tr>
<tr><td>algorithm</td><td>{{ object.algorithm }}</td></tr>
<tr><td>plimit</td><td>{{ object.plimit }}</td></tr>
</table>
<a class="btn btn-primary" href="{{object.get_update_url}}">Edit PipeLimit</a>

{% endblock %}
