{% extends "base.html" %}
{% load static %}
{% load i18n %}
{% block content %}
<p><a class="btn btn-default" href="{% url 'pyfb-kamailio:pyfb_kamailio_dialog_list' %}">Dialog Listing</a></p>
<table class="table">
<tr>
<td>ID</td><td>Link</td>
    <td>hash_entry</td>
    <td>hash_id</td>
    <td>callid</td>
    <td>from_uri</td>
    <td>from_tag</td>
    <td>to_uri</td>
    <td>to_tag</td>
    <td>caller_cseq</td>
    <td>callee_cseq</td>
    <td>caller_route_set</td>
    <td>callee_route_set</td>
    <td>caller_contact</td>
    <td>callee_contact</td>
    <td>caller_sock</td>
    <td>callee_stock</td>
    <td>state</td>
    <td>start_time</td>
    <td>timeout</td>
    <td>sflags</td>
    <td>iflags</td>
    <td>toroute_name</td>
    <td>req_uri</td>
    <td>xdata</td>
</tr>
{% for object in object_list %}
<tr>
    <td>{{object.pk}}</td>
    <td><a href="{{object.get_absolute_url}}">{{object}}</a></td>
    <td>{{ object.hash_entry }}</td>
    <td>{{ object.hash_id }}</td>
    <td>{{ object.callid }}</td>
    <td>{{ object.from_uri }}</td>
    <td>{{ object.from_tag }}</td>
    <td>{{ object.to_uri }}</td>
    <td>{{ object.to_tag }}</td>
    <td>{{ object.caller_cseq }}</td>
    <td>{{ object.callee_cseq }}</td>
    <td>{{ object.caller_route_set }}</td>
    <td>{{ object.callee_route_set }}</td>
    <td>{{ object.caller_contact }}</td>
    <td>{{ object.callee_contact }}</td>
    <td>{{ object.caller_sock }}</td>
    <td>{{ object.callee_stock }}</td>
    <td>{{ object.state }}</td>
    <td>{{ object.start_time }}</td>
    <td>{{ object.timeout }}</td>
    <td>{{ object.sflags }}</td>
    <td>{{ object.iflags }}</td>
    <td>{{ object.toroute_name }}</td>
    <td>{{ object.req_uri }}</td>
    <td>{{ object.xdata }}</td>
</tr>
{% endfor %}
</table><a class="btn btn-primary" href="{% url 'pyfb-kamailio:pyfb_kamailio_dialog_create' %}">Create new Dialog</a>
{% endblock %}
