{% extends "base.html" %}
{% load static %}
{% load i18n %}
{% block content %}
<p><a class="btn btn-default" href="{% url 'pyfb-kamailio:pyfb_kamailio_dialog_list' %}">Dialog Listing</a></p>
<table class="table">
<tr><td>hash_entry</td><td>{{ object.hash_entry }}</td></tr>
<tr><td>hash_id</td><td>{{ object.hash_id }}</td></tr>
<tr><td>callid</td><td>{{ object.callid }}</td></tr>
<tr><td>from_uri</td><td>{{ object.from_uri }}</td></tr>
<tr><td>from_tag</td><td>{{ object.from_tag }}</td></tr>
<tr><td>to_uri</td><td>{{ object.to_uri }}</td></tr>
<tr><td>to_tag</td><td>{{ object.to_tag }}</td></tr>
<tr><td>caller_cseq</td><td>{{ object.caller_cseq }}</td></tr>
<tr><td>callee_cseq</td><td>{{ object.callee_cseq }}</td></tr>
<tr><td>caller_route_set</td><td>{{ object.caller_route_set }}</td></tr>
<tr><td>callee_route_set</td><td>{{ object.callee_route_set }}</td></tr>
<tr><td>caller_contact</td><td>{{ object.caller_contact }}</td></tr>
<tr><td>callee_contact</td><td>{{ object.callee_contact }}</td></tr>
<tr><td>caller_sock</td><td>{{ object.caller_sock }}</td></tr>
<tr><td>callee_stock</td><td>{{ object.callee_stock }}</td></tr>
<tr><td>state</td><td>{{ object.state }}</td></tr>
<tr><td>start_time</td><td>{{ object.start_time }}</td></tr>
<tr><td>timeout</td><td>{{ object.timeout }}</td></tr>
<tr><td>sflags</td><td>{{ object.sflags }}</td></tr>
<tr><td>iflags</td><td>{{ object.iflags }}</td></tr>
<tr><td>toroute_name</td><td>{{ object.toroute_name }}</td></tr>
<tr><td>req_uri</td><td>{{ object.req_uri }}</td></tr>
<tr><td>xdata</td><td>{{ object.xdata }}</td></tr>
</table>
<a class="btn btn-primary" href="{{object.get_update_url}}">Edit Dialog</a>

{% endblock %}
