{% extends "base.html" %}
{% load static %}
{% load i18n %}
{% block content %}
<p><a class="btn btn-default" href="{% url 'pyfb-kamailio:pyfb_kamailio_uacreg_list' %}">UacReg Listing</a></p>
<table class="table">
<tr>
<td>ID</td><td>Link</td>
    <td>l_uuid</td>
    <td>l_username</td>
    <td>l_domain</td>
    <td>r_username</td>
    <td>r_domain</td>
    <td>realm</td>
    <td>auth_username</td>
    <td>auth_password</td>
    <td>auth_ha1</td>
    <td>auth_proxy</td>
    <td>expires</td>
    <td>flags</td>
    <td>reg_delay</td>
</tr>
{% for object in object_list %}
<tr>
    <td>{{object.pk}}</td>
    <td><a href="{{object.get_absolute_url}}">{{object}}</a></td>
    <td>{{ object.l_uuid }}</td>
    <td>{{ object.l_username }}</td>
    <td>{{ object.l_domain }}</td>
    <td>{{ object.r_username }}</td>
    <td>{{ object.r_domain }}</td>
    <td>{{ object.realm }}</td>
    <td>{{ object.auth_username }}</td>
    <td>{{ object.auth_password }}</td>
    <td>{{ object.auth_ha1 }}</td>
    <td>{{ object.auth_proxy }}</td>
    <td>{{ object.expires }}</td>
    <td>{{ object.flags }}</td>
    <td>{{ object.reg_delay }}</td>
</tr>
{% endfor %}
</table><a class="btn btn-primary" href="{% url 'pyfb-kamailio:pyfb_kamailio_uacreg_create' %}">Create new UacReg</a>
{% endblock %}
