{% extends "base.html" %}
{% load static %}
{% load i18n %}
{% block content %}
<p><a class="btn btn-default" href="{% url 'pyfb-kamailio:pyfb_kamailio_globalblacklist_list' %}">GlobalBlackList Listing</a></p>
<table class="table">
<tr><td>prefix</td><td>{{ object.prefix }}</td></tr>
<tr><td>whitelist</td><td>{{ object.whitelist }}</td></tr>
<tr><td>description</td><td>{{ object.description }}</td></tr>
</table>
<a class="btn btn-primary" href="{{object.get_update_url}}">Edit GlobalBlackList</a>

{% endblock %}
